CCL: IntClPar Struct Reference

CCL

Data Fields
IntClPar Struct Reference

## Data Fields
int | l
ccl_cosmology * | cosmo
CCL_ClTracer * | clt1
CCL_ClTracer * | clt2
int * | status

## Field Documentation

## ◆ clt1

CCL_ClTracer* IntClPar::clt1

## ◆ clt2

CCL_ClTracer* IntClPar::clt2

## ◆ cosmo

ccl_cosmology* IntClPar::cosmo

## ◆ l

int IntClPar::l

## ◆ status

int* IntClPar::status

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_cls.c